/* JavaScript file notebook-editor.js */

document.observe('dom:loaded', function () {
	var notebook = $('notebook'),
		form = $('skeleton_form_wrapper'),
		book = $('book_content'),
		sentense = $('sentense'),
		paragraphs = $$('div#sentense div'),
		selected = [],
		textAlign = $('text_align'),
		visibility = false,
		sheet = $('skeleton_form_sheet'),
		selectall = $('skeleton_form_selectall'),
		end = $('skeleton_form_end'),
		output = $('skeleton_form_output'),
		input = $('skeleton_form_input'),
		close = $('skeleton_form_close'),
		textarea = $('skeleton_text');
	
	new Draggable(form, {
		constraint: 'vertical'
	});
	
	form.hide();
	textAlign.hide();
	
	initTextarea();
	initSentense();
	
	book.observe('click', function (event) {
		if (visibility) {
			return;
		}
		form.appear({
			from: 0.2,
			to: 1.0,
			duration: 0.5,
			afterFinish: function () {
				visibility = true;
			}
		});
	});
	
	textAlign.immediateDescendants().each(function (image, index1) {
		image.observe('click', function (event) {
			var element = paragraphs.find(function (value, index2) {
				return selected[index2] === true;
			});
			if (element) {
				element.setStyle({
					textAlign: ['left', 'center', 'right'][index1]
				});
			}
		});
	});
	
	textarea.observe('focus', function (event) {
		sheet.setOpacity(0.75);
	}).observe('blur', function (event) {
		sheet.setOpacity(0.5);
	});
	
	selectall.observe('click', function (event) {
		textarea.select();
	});
	
	end.observe('click', function (event) {
		var value = textarea.getValue();
		value = value.replace(/\r/g, '').match(/[^\r\n]+|[\r\n]{2}/g);
		if (value === null) {
			return;
		}
		
		value = value.map(function (line, index) {
			if (!/\n+/.test(line)) {
				return index > 0 ? '</div><div>' + line : '<div>' + line;
			} else {
				return index > 0 ? '</div><div>&nbsp;' : '<div>&nbsp;';
			}
		});
		value.push('</div>');
		value = value.compact();
		paragraphs.invoke('stopObserving').invoke('remove');
		sentense.update(value.join(''));
		
		initSentense();
		
		textAlign.fade({
			from: 0.8,
			to: 0.0,
			duration: 0.5
		});
	});
	output.observe('click', function (event) {
		initSentense();
		var value = sentense.innerHTML;
		
		var html = '<div class="notebook">\r\n' +
			'<div class="book_header"></div>\r\n' +
			'<div class="book_content">\r\n' +
				'<div class="sentense">' + value + '</div>\r\n' +
			'</div>\r\n' +
			'<div class="book_footer"></div>\r\n' +
			'</div>';
		
		textarea.setValue(html);
	});
	input.observe('click', function (event) {
		var value = textarea.getValue(value);
		value = value.replace(/<\w+(\s+("[^"]*"|'[^']*'|[^>])+)?>|<\/\w+>/gi, '').replace(/[\t\r\n]/g, '');
		textarea.setValue(value);
	});
	close.observe('click', function (event) {
		form.fade({
			from: 0.8,
			to: 0.0,
			duration: 0.5,
			afterFinish: function () {
				visibility = false;
			}
		});
	});
	
	function initTextarea() {
		var value = sentense.innerHTML;
		value = value.replace(/[\t\r\n]/g, '').replace(/<\w+(\s+("[^"]*"|'[^']*'|[^>])+)?>/gi, '').replace(/<\/\w+>/gi, '\r\n').replace(/\r\n$/, '');
		textarea.setValue(value);
	}
	function initSentense() {
		selected.length = 0;
		paragraphs = $$('div#sentense div');
		paragraphs.each(function (element, index) {
			selected[index] = false;
			element.observe('click', function (event) {
				if (!visibility) {
					return;
				}
				if (!selected[index]) {
					var offset = notebook.cumulativeOffset(),
						pointerX = Event.pointerX(event),
						pointerY = Event.pointerY(event);
					selected[index] = true;
					textAlign.setStyle({
						left: (pointerX - offset.left + 10) + 'px',
						top: pointerY - offset.top + 'px'
					}).appear({
						from: 0.2,
						to: 1.0,
						duration: 0.5
					});
					element.setStyle({
						backgroundColor: '#333'
					});
				} else {
					selected[index] = false;
					textAlign.fade({
						from: 0.8,
						to: 0.0,
						duration: 0.5
					});
					element.setStyle({
						backgroundColor: 'transparent'
					});
				}
			});
		});
	}
});